pycocoa.printers.PaperCustom

Package pycocoa :: Module printers :: Class PaperCustom |
[frames] | no frames]

# Class PaperCustom

              object --+
                       |
    internals._Objectype --+
                           |
            baseTypes._Type0 --+
                               |
                       _PM_Type0 --+
                                   |
                               Paper --+
                                       |
                                      PaperCustom

Create a custom Paper.

Instance Methods
__init__(self, name=`'``Custom``'`, ID='', width=612, height=792, margins=None, printer=None) New PaperCustom from paper attributes. |
Inherited from `Paper`: `localname` Inherited from `_PM_Type0`: `__str__`, `release`, `retain` Inherited from `baseTypes._Type0`: `__repr__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `Paper`: `ID`, `PPD`, `height`, `isCustom`, `margins`, `name`, `printer`, `size2inch`, `size2mm`, `width` Inherited from `_PM_Type0`: `PM` Inherited from `baseTypes._Type0`: `NS`, `NSDelegate` Inherited from `internals._Objectype`: `typename` Inherited from `object`: `__class__`

Method Details

### __init__(self, name=`'``Custom``'`, ID='', width=612, height=792, margins=None, printer=None) (Constructor) |
New PaperCustom from paper attributes. Raises: `TypeError` - Invalid margins or printer. Overrides: object.__init__